@@ -80,8 +80,8 @@ global PgAcVar CurrentDB
 		}
 	}
 	set PgAcVar(tblinfo,indexlist) {}
-	wpg_select $CurrentDB "select oid,indexrelid from pg_index where (pg_class.relname='$PgAcVar(tblinfo,tablename)') and (pg_class.oid=pg_index.indrelid)" rec {
-		lappend PgAcVar(tblinfo,indexlist) $rec(oid)
+	wpg_select $CurrentDB "select indexrelid from pg_index, pg_class where (pg_class.relname='$PgAcVar(tblinfo,tablename)') and (pg_class.oid=pg_index.indrelid)" rec {
+		lappend PgAcVar(tblinfo,indexlist) $rec(indexrelid)
 		wpg_select $CurrentDB "select relname from pg_class where oid=$rec(indexrelid)" rec1 {
 			.pgaw:TableInfo.f2.fl.ilb insert end $rec1(relname)
 		}
@@ -815,7 +815,7 @@ if {$PgAcVar(mw,$wn,updatable)} then {
 	$wn.c bind q <Key> "Tables::editText $wn %A %K"
 	if {[info commands kanjiInput] == "kanjiInput"} then {
 		$wn.c bind q <Control-backslash> "pgaccess_kinput_start %W";
-		$wn.c bind q <Control-Kanji> "pg_access_kinput_start %W";
+		$wn.c bind q <Control-Kanji> "pgaccess_kinput_start %W";
 	}
 } else {
 	$wn.c bind q <Key> {}
@@ -2175,7 +2175,7 @@ proc vTclWindow.pgaw:Permissions {base} {
 #
 # This file contains Tcl procedures used to input Japanese text.
 #
-# $Header: /home/projects/pgsql/cvsroot/pgsql/src/bin/pgaccess/lib/tables.tcl,v 1.7 2001/02/26 05:15:48 ishii Exp $
+# $Header: /cvsroot/pgsql/src/bin/pgaccess/lib/Attic/tables.tcl,v 1.10.2.1 2002/02/18 04:12:34 ishii Exp $
 #
 # Copyright (c) 1993  Software Research Associates, Inc.
 #
